****************************
Provenance tracker decorator
****************************

The Alpaca class decorator can be used to instrument the functions used in
the script, to track the inputs, outputs, and parameters.

.. autoclass:: alpaca.Provenance
